/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2009-2010 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "BinaryCollisionModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

template<class CloudType>
Foam::autoPtr<Foam::BinaryCollisionModel<CloudType> >
Foam::BinaryCollisionModel<CloudType>::New
(
    const dictionary& dict,
    CloudType& owner
)
{
    word BinaryCollisionModelType(dict.lookup("BinaryCollisionModel"));

    Info<< "Selecting BinaryCollisionModel "
        << BinaryCollisionModelType
        << endl;

    typename dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find(BinaryCollisionModelType);

    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorIn
        (
            "BinaryCollisionModel<CloudType>::New"
            "(const dictionary&, CloudType&)"
        )
            << "Unknown BinaryCollisionModelType type "
            << BinaryCollisionModelType
            << ", constructor not in hash table" << nl << nl
            << "    Valid BinaryCollisionModel types are:" << nl
            << dictionaryConstructorTablePtr_->sortedToc() << exit(FatalError);
    }

    return autoPtr<BinaryCollisionModel<CloudType> >
    (
        cstrIter()(dict, owner)
    );
}


// ************************ vim: set sw=4 sts=4 et: ************************ //
